@@ -96,14 +96,6 @@ PortalSession::PortalSession(Server *server)
         qCWarning(KRDP) << "Could not connect to Freedesktop Remote Desktop Portal";
         return;
     }
-
-    qCDebug(KRDP) << "Initializing Freedesktop Portal Session";
-
-    auto parameters = QVariantMap{
-        {QStringLiteral("handle_token"), createHandleToken()},
-        {QStringLiteral("session_handle_token"), createHandleToken()},
-    };
-    new PortalRequest(d->remoteInterface->CreateSession(parameters), this, &PortalSession::onCreateSession);
 }
 
 PortalSession::~PortalSession()
@@ -121,6 +113,17 @@ PortalSession::~PortalSession()
     qCDebug(KRDP) << "Closing Freedesktop Portal Session";
 }
 
+void PortalSession::start()
+{
+    qCDebug(KRDP) << "Initializing Freedesktop Portal Session";
+
+    auto parameters = QVariantMap{
+        {QStringLiteral("handle_token"), createHandleToken()},
+        {QStringLiteral("session_handle_token"), createHandleToken()},
+    };
+    new PortalRequest(d->remoteInterface->CreateSession(parameters), this, &PortalSession::onCreateSession);
+}
+
 void PortalSession::sendEvent(const std::shared_ptr<QEvent> &event)
 {
     auto encodedStream = stream();
@@ -210,11 +213,13 @@ void PortalSession::onDevicesSelected(uint code, const QVariantMap & /*result*/)
         return;
     }
 
-    auto parameters = QVariantMap{
-        {QStringLiteral("types"), 1u}, // only MONITOR is supported
-        {QStringLiteral("multiple"), activeStream() >= 0},
-        {QStringLiteral("handle_token"), createHandleToken()},
-    };
+    QVariantMap parameters;
+    if (virtualMonitor()) {
+        parameters = {{QStringLiteral("types"), 4u}}; // VIRTUAL
+    } else {
+        parameters = {{QStringLiteral("types"), 1u}, // MONITOR
+                      {QStringLiteral("multiple"), activeStream() >= 0}};
+    }
 
     new PortalRequest(d->screencastInterface->SelectSources(d->sessionPath, parameters), this, &PortalSession::onSourcesSelected);
 }
